@@ -133,7 +133,8 @@ class WeixinPay(object):
         if data["trade_type"] == "NATIVE" and "product_id" not in data:
             raise WeixinPayError("trade_type为NATIVE时，product_id为必填参数")
         data.setdefault("notify_url", self.notify_url)
-        data.setdefault("spbill_create_ip", self.remote_addr)
+        if "spbill_create_ip" not in data:
+            data.setdefault("spbill_create_ip", self.remote_addr)
 
         raw = self._fetch(url, data)
         return raw
@@ -151,7 +152,7 @@ class WeixinPay(object):
         raw = dict(appId=self.app_id, timeStamp=timestamp,
                    nonceStr=nonce_str, package=package, signType="MD5")
         sign = self.sign(raw)
-        return dict(package=package, appId=self.app_id,
+        return dict(package=package, appId=self.app_id, signType="MD5",
                     timeStamp=timestamp, nonceStr=nonce_str, sign=sign)
 
     def order_query(self, **data):
